==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Persona/Persona.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { PersonaSize, PersonaPresence } from './Persona.types.js';
import { PersonaCoin } from './PersonaCoin/index.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var PersonaBase = function (_BaseComponent) {
  _inherits(PersonaBase, _BaseComponent);

  var _super = _createSuper(PersonaBase);

  function PersonaBase() {
    var _this;

    _classCallCheck(this, PersonaBase);

    _this = _super.apply(this, arguments);
    _this.PersonaSize = PersonaSize;
    return _this;
  }

  _createClass(PersonaBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          coinSize = this.coinSize,
          text = this.text,
          secondaryText = this.secondaryText,
          tertiaryText = this.tertiaryText,
          optionalText = this.optionalText,
          hidePersonaDetails = this.hidePersonaDetails,
          size = this.size;
      return h("div", {
        "class": classNames.root,
        "style": coinSize ? {
          height: "".concat(coinSize, "px"),
          minWidth: "".concat(coinSize, "px")
        } : {}
      }, [h(PersonaCoin, {
        "props": _objectSpread({}, this.$props)
      }), (!hidePersonaDetails || size === PersonaSize.size8 || size === PersonaSize.size10 || size === PersonaSize.tiny) && h("div", {
        "class": classNames.details
      }, [h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.primaryText
      }, [h("div", [text])]), h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.secondaryText
      }, [h("div", [secondaryText])]), h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.tertiaryText
      }, [h("div", [tertiaryText])]), h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.optionalText
      }, [h("div", [optionalText])]), this.$slots["default"]])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          showSecondaryText = this.showSecondaryText,
          presence = this.presence,
          size = this.size;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        showSecondaryText: showSecondaryText,
        presence: presence,
        size: size
      });
    }
  }]);

  return PersonaBase;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "allowPhoneInitials", void 0);

__decorate([Prop({
  type: Number,
  "default": PersonaPresence.none
}), __metadata("design:type", Number)], PersonaBase.prototype, "presence", void 0);

__decorate([Prop({
  type: Number,
  "default": PersonaSize.size48
}), __metadata("design:type", Number)], PersonaBase.prototype, "size", void 0);

__decorate([Prop({
  type: Number,
  "default": 0
}), __metadata("design:type", Number)], PersonaBase.prototype, "coinSize", void 0);

__decorate([Prop({
  type: [Number, String],
  "default": undefined
}), __metadata("design:type", Number)], PersonaBase.prototype, "initialsColor", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "hidePersonaDetails", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], PersonaBase.prototype, "text", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], PersonaBase.prototype, "secondaryText", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], PersonaBase.prototype, "tertiaryText", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], PersonaBase.prototype, "optionalText", void 0);

__decorate([Prop({
  type: String,
  "default": undefined
}), __metadata("design:type", String)], PersonaBase.prototype, "imageUrl", void 0);

__decorate([Prop({
  type: String,
  "default": 'online'
}), __metadata("design:type", String)], PersonaBase.prototype, "status", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "isOutOfOffice", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "showSecondaryText", void 0);

PersonaBase = __decorate([Component], PersonaBase);

export { PersonaBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Persona/Persona.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.symbol';
import 'core-js/modules/es.array.filter';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.object.get-own-property-descriptor';
import 'core-js/modules/es.object.get-own-property-descriptors';
import 'core-js/modules/es.object.keys';
import 'core-js/modules/web.dom-collections.for-each';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import 'core-js/modules/es.number.constructor';
import { PersonaSize, PersonaPresence } from './Persona.types.js';
import { PersonaCoin } from './PersonaCoin/index.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var PersonaBase = function (_BaseComponent) {
  _inherits(PersonaBase, _BaseComponent);

  var _super = _createSuper(PersonaBase);

  function PersonaBase() {
    var _this;

    _classCallCheck(this, PersonaBase);

    _this = _super.apply(this, arguments);
    _this.PersonaSize = PersonaSize;
    return _this;
  }

  _createClass(PersonaBase, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          coinSize = this.coinSize,
          text = this.text,
          secondaryText = this.secondaryText,
          tertiaryText = this.tertiaryText,
          optionalText = this.optionalText,
          hidePersonaDetails = this.hidePersonaDetails,
          size = this.size;
      return h("div", {
        "class": classNames.root,
        "style": coinSize ? {
          height: "".concat(coinSize, "px"),
          minWidth: "".concat(coinSize, "px")
        } : {}
      }, [h(PersonaCoin, {
        "props": _objectSpread({}, this.$props)
      }), (!hidePersonaDetails || size === PersonaSize.size8 || size === PersonaSize.size10 || size === PersonaSize.tiny) && h("div", {
        "class": classNames.details
      }, [h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.primaryText
      }, [h("div", [text])]), h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.secondaryText
      }, [h("div", [secondaryText])]), h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.tertiaryText
      }, [h("div", [tertiaryText])]), h("div", {
        "attrs": {
          "dir": "auto"
        },
        "class": classNames.optionalText
      }, [h("div", [optionalText])]), this.$slots.default])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          showSecondaryText = this.showSecondaryText,
          presence = this.presence,
          size = this.size;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        showSecondaryText: showSecondaryText,
        presence: presence,
        size: size
      });
    }
  }]);

  return PersonaBase;
}(BaseComponent);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "allowPhoneInitials", void 0);

__decorate([Prop({
  type: Number,
  default: PersonaPresence.none
}), __metadata("design:type", Number)], PersonaBase.prototype, "presence", void 0);

__decorate([Prop({
  type: Number,
  default: PersonaSize.size48
}), __metadata("design:type", Number)], PersonaBase.prototype, "size", void 0);

__decorate([Prop({
  type: Number,
  default: 0
}), __metadata("design:type", Number)], PersonaBase.prototype, "coinSize", void 0);

__decorate([Prop({
  type: [Number, String],
  default: undefined
}), __metadata("design:type", Number)], PersonaBase.prototype, "initialsColor", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "hidePersonaDetails", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "text", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "secondaryText", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "tertiaryText", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], PersonaBase.prototype, "optionalText", void 0);

__decorate([Prop({
  type: String,
  default: undefined
}), __metadata("design:type", String)], PersonaBase.prototype, "imageUrl", void 0);

__decorate([Prop({
  type: String,
  default: 'online'
}), __metadata("design:type", String)], PersonaBase.prototype, "status", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "isOutOfOffice", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], PersonaBase.prototype, "showSecondaryText", void 0);

PersonaBase = __decorate([Component], PersonaBase);

export { PersonaBase };
